package ruizide

import (
	"encoding/json"
	"eta/eta_data_analysis/models"
	"eta/eta_data_analysis/utils"
	"github.com/xuri/excelize/v2"
	"os"
	"path/filepath"
)

const (
	OilDemandAnalysis = "Oil Demand Analysis"
	SheetName         = "Chart 1"
)

var (
	OilDemandAnalysisConfigMap = map[string]OSAPConfig{
		"Oil_Demand_Analysis_Product_Detail": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Product detail",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Region": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Region",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Scenario": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Scenario",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Continent": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Continent",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Country": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Country",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Product_Category": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Product category",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Sector_Detail": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Sector detail",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
		"Oil_Demand_Analysis_Sector_Category": {
			Frequency:          "月度",
			Unit:               "千桶每天",
			IndexNameColSuffix: "Sector category",
			IndexRow:           2,
			DataRow:            1,
			DateRow:            0,
		},
	}
)

type OilDemandAnalysisProcessor struct {
}

func (p *OilDemandAnalysisProcessor) Process(tableName string) (err error) {
	var fileName string
	// 解析表格
	fileName = tableName + "_" + utils.GetCurrentYearMonth() + ".xlsx"
	filePath := filepath.Join(excelDir, fileName)
	if _, err = os.Stat(filePath); os.IsNotExist(err) {
		utils.FileLog.Error("文件不存在: %v", err)
		return
	}
	// 打开 Excel 文件
	file, err := excelize.OpenFile(filePath)
	if err != nil {
		utils.FileLog.Error("无法打开 Excel 文件: %v", err)
		return
	}
	classifyIds, err := dealClassify(CubeDashboards, []string{OilDemandAnalysis})
	// 获取所有工作表
	if err != nil {
		utils.FileLog.Error("获取分类Id失败: %v", err)
		return
	}
	//按照sheet页来处理数据,一个sheet发送一次服务器
	var indexMap = make(map[string]*models.IndexInfo)
	// 获取工作表的最大行数
	dataRows, excelErr := file.GetRows(SheetName) // 直接获取所有行数据
	if excelErr != nil {
		utils.FileLog.Error("获取工作表数据时出错: %v", excelErr)
		return
	}
	if sheetConfig, ok := OilDemandAnalysisConfigMap[tableName]; ok {
		// 匹配非数字字符
		classifyId := classifyIds[OilDemandAnalysis]
		indexMap, err = DataHandler(dataRows, sheetConfig, classifyId, OilDemandAnalysis)
		// 新增数据源指标数据
		if len(indexMap) > 0 {
			for _, index := range indexMap {
				pars := chunkIndexData(index, rzdBatchSize)
				for _, par := range pars {
					// 转换成json
					marshal, parseErr := json.Marshal(par)
					if parseErr != nil {
						utils.FileLog.Error("json.Marshal err: %v", parseErr)
						return parseErr
					}
					// 发送 HTTP POST 请求
					_, err = utils.HttpPostRequest(utils.EDB_LIB_URL+utils.ADD_BATCH_RZD_DATA, string(marshal), "application/json")
					if err != nil {
						utils.FileLog.Error("postEdbLib err: %v", err)
						return err
					}
				}
			}
		}
	}
	return
}
